@@ -4,24 +4,15 @@ from . import constants
 from .action_descriptor import ActionDescriptor
 from .action_reference import ActionReference
 from .application import Application
-from .colors import CMYKColor
-from .colors import GrayColor
-from .colors import HSBColor
-from .colors import LabColor
-from .colors import RGBColor
+from .colors import CMYKColor, GrayColor, HSBColor, LabColor, RGBColor
 from .enumerations import *
-from .errors import PhotoshopPythonAPICOMError
-from .errors import PhotoshopPythonAPIError
+from .errors import PhotoshopPythonAPICOMError, PhotoshopPythonAPIError
 from .event_id import EventID
 from .open_options import EPSOpenOptions
-from .save_options import BMPSaveOptions
-from .save_options import ExportOptionsSaveForWeb, PNGSaveOptions
-from .save_options import GIFSaveOptions
-from .save_options import JPEGSaveOptions
-from .save_options import PDFSaveOptions
-from .save_options import PhotoshopSaveOptions
-from .save_options import TargaSaveOptions
-from .save_options import TiffSaveOptions
+from .save_options import (BMPSaveOptions, ExportOptionsSaveForWeb,
+                           GIFSaveOptions, JPEGSaveOptions, PDFSaveOptions,
+                           PhotoshopSaveOptions, PNGSaveOptions,
+                           TargaSaveOptions, TiffSaveOptions)
 from .solid_color import SolidColor
 from .text_item import TextItem
 
