@@ -3,10 +3,8 @@
 # Import built-in modules
 import os
 import platform
-
 import winreg
-from typing import Any
-from typing import List
+from typing import Any, List
 
 # Import third-party modules
 from comtypes.client import CreateObject
@@ -37,8 +35,7 @@ class Photoshop(object):
                 self.app = self.instance_app(self._get_program_id())
             except OSError:
                 raise PhotoshopPythonAPIError(
-                    "Please check if you have "
-                    "Photoshop installed correctly.",
+                    "Please check if you have " "Photoshop installed correctly.",
                 )
         if parent:
             self.adobe = self.app
@@ -80,8 +77,7 @@ class Photoshop(object):
         return winreg.OpenKey(
             winreg.HKEY_LOCAL_MACHINE,
             key,
-            access=winreg.KEY_READ | mappings.get(machine_type,
-                                                  winreg.KEY_WOW64_32KEY),
+            access=winreg.KEY_READ | mappings.get(machine_type, winreg.KEY_WOW64_32KEY),
         )
 
     def get_application_path(self):
