@@ -1,6 +1,6 @@
 from ._core import Photoshop
-from .errors import PhotoshopPythonAPIError
 from ._layerSet import LayerSet
+from .errors import PhotoshopPythonAPIError
 
 
 class LayerSets(Photoshop):
@@ -27,9 +27,11 @@ class LayerSets(Photoshop):
     def item(self, index):
         return LayerSet(self.app.item(index))
 
+    def removeAll(self):
+        self.app.removeAll()
+
     def getByName(self, name):
         for layer in self.app:
             if name == layer.name:
                 return LayerSet(layer)
-        raise PhotoshopPythonAPIError("Could not find a LayerSet named "
-                                      f'"{name}"')
+        raise PhotoshopPythonAPIError(f'Could not find a LayerSet named "{name}"')
