@@ -8,8 +8,8 @@ Notifiers must be enabled using the Application.notifiersEnabled property.
 
 """
 
-from typing import Any
-from typing import Optional
+from typing import Any, Optional
+
 from ._core import Photoshop
 from ._notifier import Notifier
 
@@ -36,8 +36,9 @@ class Notifiers(Photoshop):
     def length(self):
         return len(self._notifiers)
 
-    def add(self, event, event_file: Optional[Any] = None,
-            event_class: Optional[Any] = None) -> Notifier:
+    def add(
+        self, event, event_file: Optional[Any] = None, event_class: Optional[Any] = None
+    ) -> Notifier:
         self.parent.notifiersEnabled = True
         return Notifier(self.app.add(event, event_file, event_class))
 
