@@ -6,17 +6,21 @@ class TextFont(Photoshop):
         super().__init__(parent=parent)
 
     @property
-    def family(self):
+    def family(self) -> str:
+        """The font family"""
         return self.app.family
 
     @property
     def name(self):
+        """The name of the font."""
         return self.app.name
 
     @property
     def postScriptName(self):
+        """The PostScript name of the font."""
         return self.app.postScriptName
 
     @property
     def style(self):
+        """The font style."""
         return self.app.style
